@@ -1,4 +1,4 @@
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Optional
 
 from arrow_bpmn.__spi__.registry.node_ref import NodeRef
@@ -14,15 +14,16 @@ class State:
     reference: NodeRef
     is_reentry: bool = False
     parent_reference: Optional[NodeRef] = None
+    headers: dict = field(default_factory=lambda: {})
 
     def with_is_reentry(self, is_reentry: bool):
-        return State(self.properties, self.reference, is_reentry, self.parent_reference)
+        return State(self.properties, self.reference, is_reentry, self.parent_reference, self.headers)
 
     def with_parent_reference(self, parent_reference: Optional[NodeRef]):
-        return State(self.properties, self.reference, self.is_reentry, parent_reference)
+        return State(self.properties, self.reference, self.is_reentry, parent_reference, self.headers)
 
     def with_reference(self, reference: NodeRef):
-        return State(self.properties, reference, self.is_reentry, self.parent_reference)
+        return State(self.properties, reference, self.is_reentry, self.parent_reference, self.headers)
 
     def __setitem__(self, key, value):
         self.properties[key] = value
