@@ -10,7 +10,7 @@ from arrow_bpmn.__spi__.registry.process_ref import ProcessRef
 class EventRegistry(ABC):
 
     @abstractmethod
-    def create_subscription(self, event: Event, node_ref: NodeRef):
+    def create_subscription(self, event: Event, node_ref: NodeRef, consumable: bool):
         pass
 
     @abstractmethod
@@ -18,7 +18,7 @@ class EventRegistry(ABC):
         pass
 
     @abstractmethod
-    def get_subscriptions(self, event: Event, consume: bool = True) -> List[NodeRef]:
+    def get_subscriptions(self, event: Event) -> List[NodeRef]:
         pass
 
 
@@ -82,10 +82,11 @@ class UserEvent(Event):
     process_id: str
     node_id: str
     attributes: dict
-    
+
     def __repr__(self):
         return f"{self.group}:{self.process_id}:{self.node_id}"
 
+
 @dataclass
 class ManualEvent(Event):
     process_id: str
