@@ -1,6 +1,6 @@
 import logging
 import uuid
-from typing import List, Optional
+from typing import List
 
 from arrow_bpmn.__spi__ import CompleteAction, IncidentAction
 from arrow_bpmn.__spi__ import NodeRef
@@ -13,6 +13,7 @@ from arrow_bpmn.__spi__.action.resume_action import ResumeAction
 from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.__spi__.registry.event import Event
+from arrow_bpmn.__spi__.types import OptDict
 from arrow_bpmn.engine.abstract_engine import BpmnEngine, ProcessRef
 from arrow_bpmn.engine.registry.abstract_event_registry import NoneEvent
 
@@ -27,23 +28,22 @@ def first(iterable):
 
 class SequentialBpmnEngine(BpmnEngine):
 
-    def invoke_by_event(self, event: Event, init_state: Optional[dict] = None) -> List[State]:
+    def invoke_by_event(self, event: Event, init_state: OptDict = None, headers: OptDict = None) -> List[State]:
         def invoke(subscription: NodeRef):
             process = self.process_store.read_process(ProcessRef(event.group, subscription.process_id))
             environment = Environment(event.group, process, self.factories)
 
             is_reentry = not environment.is_start_event(subscription.node_id)
-            state = State(init_state or {}, subscription, is_reentry)
+            state = State(init_state or {}, subscription, is_reentry, headers=headers)
 
             result = self._handle_action(ContinueAction(subscription.node_id), state, environment)
             return result[0]
 
-        # FIXME: consume if target is not a start event
-        subscriptions = self.event_registry.get_subscriptions(event, consume=False)
+        subscriptions = self.event_registry.get_subscriptions(event)
         assert len(subscriptions) > 0, "no subscriptions found"
         return list(map(invoke, subscriptions))
 
-    def resume_by_event(self, event: Event, init_state: Optional[dict] = None) -> List[State]:
+    def resume_by_event(self, event: Event) -> List[State]:
         def resume_process(node_ref: NodeRef) -> List[State]:
             state = self.process_store.read_state(node_ref)
             process = self.process_store.read_process(ProcessRef(event.group, node_ref.process_id))
@@ -55,8 +55,8 @@ class SequentialBpmnEngine(BpmnEngine):
         node_refs = self.event_registry.get_subscriptions(event)
         return flatten([resume_process(node_ref) for node_ref in node_refs])
 
-    def invoke_by_id(self, ref: ProcessRef, init_state: Optional[dict] = None) -> State:
-        return self.invoke_by_event(NoneEvent(ref.group, ref.process_id), init_state)[0]
+    def invoke_by_id(self, ref: ProcessRef, init_state: OptDict = None, headers: OptDict = None) -> State:
+        return self.invoke_by_event(NoneEvent(ref.group, ref.process_id), init_state, headers)[0]
 
     def _handle_action(self, action: Action, state: State, env: Environment) -> List[State]:
         logging.info(action)
@@ -102,7 +102,7 @@ class SequentialBpmnEngine(BpmnEngine):
 
             if action.event is not None:
                 # register an event subscription to get ready for an ResumeAction
-                self.event_registry.create_subscription(action.event, state.reference)
+                self.event_registry.create_subscription(action.event, state.reference, action.consumable)
                 # return the state as the intermediate result of the process
                 return [state]
 
