@@ -15,8 +15,11 @@ class InMemoryProcessStore(ProcessStore):
     def write_process(self, group: str, process: Process):
         self.process_cache[group + ":" + process.id] = process
 
+    def delete_process(self, process_ref: ProcessRef):
+        del self.process_cache[str(process_ref)]
+
     def read_process(self, ref: ProcessRef) -> Process:
-        return self.process_cache[ref.group + ":" + ref.process_id]
+        return self.process_cache[str(ref)]
 
     def write_state(self, state: State):
         self.state_cache[str(state.reference)] = state
