@@ -31,7 +31,7 @@ class SignalStartEvent(NoneStartEvent, EventRegistryAware):
 
     def with_event_registry(self, process_ref: ProcessRef, event_registry: EventRegistry):
         event = SignalEvent(process_ref.group, self.signal)
-        event_registry.create_subscription(event, NodeRef(process_ref.group, process_ref.process_id, self.id))
+        event_registry.create_subscription(event, NodeRef(process_ref.group, process_ref.process_id, self.id), False)
 
     def __repr__(self):
         return f"SignalStartEvent({self.id})"
